@@ -1,6 +1,7 @@
 # encoding=utf-8
 
 import subprocess
+from pathlib import Path
 
 import pytest
 
@@ -45,3 +46,16 @@ def test_zypper_fail(capsys, mocker):
     output = capsys.readouterr()
     assert 'zypper_scrape_success 0' in output.out
     assert 'Failed' in output.err
+
+
+def test_output_file(capsys, mocker, tmp_path: Path):
+    mock_zypper_call(mocker, 'tests/fixtures/all.xml')
+    target_file_path = tmp_path / 'zypper.prom'
+
+    main(['--output-file', str(target_file_path)])
+
+    cli_output = capsys.readouterr()
+    assert cli_output.out == '' and cli_output.err == ''
+    file_output = target_file_path.read_text()
+    assert 'zypper_scrape_success 1' in file_output
+    assert 'zypper_applicable_patches{category="optional",severity="moderate"} 2' in file_output
